.. finufft documentation master file. This also contains what appears on the
   front HTML page.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   Barnett 8/27/20: this is HTML only; split out separate latexindex.rst

.. _index:

Flatiron Institute Nonuniform Fast Fourier Transform
========================================================

.. include:: overview.src


Documentation contents
========================

.. toctree::
   :maxdepth: 3

   install
   install_gpu
   dirs
   math
   cex
   c
   c_gpu
   opts
   error
   trouble
   performance
   tut
   fortran
   matlab
   python
   python_gpu
   julia
   changelog
   nfft_migr
   cufinufft_migration
   devnotes
   related
   users
   ackn
   refs
